Module error

Module error 

Error types returned by this crate’s fallible operations.

Enums

NdnError
The general-purpose error type for this crate.
SignError
Errors that can occur while signing an Interest.
VerifyError
Errors that can occur while verifying a signed Interest or Data packet.

Type Aliases

Result
The Result type used throughout this crate, with the error type fixed to NdnError.