pub enum VerifyError {
InvalidParameterDigest,
InvalidSignature,
MissingSignatureInfo,
MissingApplicationParameters,
UnknownSignMethod,
}Variants
InvalidParameterDigest
The name’s ParametersSha256DigestComponent doesn’t match the
signed application parameters.
InvalidSignature
The signature doesn’t match the signed content.
MissingSignatureInfo
The packet is signed but carries no signature info.
MissingApplicationParameters
The packet is signed but has no application parameters to include in the signature.
UnknownSignMethod
The signature’s type isn’t recognized by the verifier being used.